diff fifo.h @ 493:97dd9756349c libavutil

cosmetics (by Bj«Órn Axelsson)
author benoit
date Wed, 09 Apr 2008 11:36:50 +0000
parents 75f096258d14
children e3d6654d68f0
line wrap: on
line diff
--- a/fifo.h	Wed Apr 09 11:35:16 2008 +0000
+++ b/fifo.h	Wed Apr 09 11:36:50 2008 +0000
@@ -81,16 +81,16 @@
 /**
  * Feeds data from a user supplied callback to an AVFifoBuffer.
  * @param *f AVFifoBuffer to write to
- * @param *buf data source
+ * @param *src data source
  * @param size number of bytes to write
  * @param *func generic write function. First parameter is buf,
  * second is dest_buf, third is dest_buf_size.
  * func must return the number of bytes written to dest_buf, or <= 0 to
  * indicate no more data available to write.
  * If func is NULL, buf is interpreted as a simple byte array for source data.
  * @return the number of bytes written to the fifo.
  */
-int av_fifo_generic_write(AVFifoBuffer *f, void *buf, int size, int (*func)(void*, void*, int));
+int av_fifo_generic_write(AVFifoBuffer *f, void *src, int size, int (*func)(void*, void*, int));
 
 /**
  * Resizes an AVFifoBuffer.
@@ -81,16 +81,16 @@
  * @param size number of bytes to write
- * @param *func generic write function. First parameter is buf,
+ * @param *func generic write function. First parameter is src,
  * second is dest_buf, third is dest_buf_size.
  * func must return the number of bytes written to dest_buf, or <= 0 to
@@ -81,16 +81,16 @@
  * func must return the number of bytes written to dest_buf, or <= 0 to
  * indicate no more data available to write.
- * If func is NULL, buf is interpreted as a simple byte array for source data.
+ * If func is NULL, src is interpreted as a simple byte array for source data.
  * @return the number of bytes written to the fifo.
  */